@@ -65,7 +65,7 @@ def exception_handler(oType, oValue, oTraceback):
     oErrorDlg.run()
     oErrorDlg.destroy()
 
-def main(aArgs):
+def main():
     """Start the Sutekh Gui.
 
        Check that database exists, doesn't need to be upgraded, then
@@ -75,7 +75,7 @@ def main(aArgs):
     # handle exceptions with a GUI dialog
     sys.excepthook = exception_handler
 
-    oOptParser, (oOpts, aArgs) = parse_options(aArgs)
+    oOptParser, (oOpts, aArgs) = parse_options(sys.argv)
     sPrefsDir = prefs_dir("Sutekh")
 
     if len(aArgs) != 1:
@@ -140,6 +140,6 @@ def main(aArgs):
     oConfig.write()
 
 if __name__ == "__main__":
-    sys.exit(main(sys.argv))
+    sys.exit(main())
 
 
