@@ -1419,6 +1419,7 @@ class CardSetCardListModel(CardListModel):
             if bRemove:
                 self._remove_sub_iters(sCardName)
                 self.remove(oIter)
+                iParGrpCnt -= iParCnt
             else:
                 self._update_entry(oIter, iCnt, iParCnt)
 
@@ -1576,13 +1577,18 @@ class CardSetCardListModel(CardListModel):
         if len(self._dName2Iter[sCardName]) > 0 and iChg < 0:
             # Test if we need to remove entries
             oIter = self._dName2Iter[sCardName][0]
+            iParCnt = self.get_int_value(oIter, 2)
             bRemove = not self.check_card_iter_stays(oIter)
         if bRemove:
             # Remove the card entry
             for oIter in self._dName2Iter[sCardName]:
                 oGrpIter = self.iter_parent(oIter)
+                iGrpCnt = self.get_int_value(oGrpIter, 1)
+                iParGrpCnt = self.get_int_value(oGrpIter, 2) - iParCnt
                 self._remove_sub_iters(sCardName)
                 self.remove(oIter)
+                self.set(oGrpIter, 2, self.format_parent_count(iParGrpCnt,
+                    iGrpCnt))
                 if not self.check_group_iter_stays(oGrpIter):
                     sGroupName = self.get_value(oGrpIter, 0)
                     del self._dGroupName2Iter[sGroupName]
