@@ -167,7 +167,8 @@ class CardDict(dict):
         for sExp, sRarSet in aExp:
             for sRar in sRarSet.split('/'):
                 oPair = self._oMaker.make_rarity_pair(sExp, sRar)
-                oCard.addRarityPair(oPair)
+                if oPair not in oCard.rarity:
+                    oCard.addRarityPair(oPair)
 
     def _add_disciplines(self, oCard, sDis):
         """Add the list of disciplines to the card, creating discipline
@@ -182,7 +183,8 @@ class CardDict(dict):
                 oPair = self._oMaker.make_discipline_pair(sVal, 'inferior')
             else:
                 oPair = self._oMaker.make_discipline_pair(sVal, 'superior')
-            oCard.addDisciplinePair(oPair)
+            if oPair not in oCard.discipline:
+                oCard.addDisciplinePair(oPair)
 
     def _add_virtues(self, oCard, sVir):
         """Add the list of virtues to the card."""
@@ -193,7 +195,8 @@ class CardDict(dict):
 
         for sVal in sVir.split():
             oVirt = self._oMaker.make_virtue(sVal)
-            oCard.addVirtue(oVirt)
+            if oVirt not in oCard.virtue:
+                oCard.addVirtue(oVirt)
 
     def _add_creeds(self, oCard, sCreed):
         """Add creeds to the card."""
@@ -203,7 +206,9 @@ class CardDict(dict):
             return
 
         for sVal in sCreed.split('/'):
-            oCard.addCreed(self._oMaker.make_creed(sVal.strip()))
+            oCreed = self._oMaker.make_creed(sVal.strip())
+            if oCreed not in oCard.creed:
+                oCard.addCreed(oCreed)
 
     def _add_clans(self, oCard, sClan):
         """Add clans to the card."""
@@ -213,7 +218,9 @@ class CardDict(dict):
             return
 
         for sVal in sClan.split('/'):
-            oCard.addClan(self._oMaker.make_clan(sVal.strip()))
+            oClan = self._oMaker.make_clan(sVal.strip())
+            if oClan not in oCard.clan:
+                oCard.addClan(oClan)
 
     def _add_cost(self, oCard, sCost):
         """Add the cost to the card, replace 'X' with -1."""
@@ -276,15 +283,21 @@ class CardDict(dict):
     def _add_card_type(self, oCard, sTypes):
         """Add the card type info to the card."""
         for sVal in sTypes.split('/'):
-            oCard.addCardType(self._oMaker.make_card_type(sVal.strip()))
+            oType = self._oMaker.make_card_type(sVal.strip())
+            if oType not in oCard.cardtype:
+                oCard.addCardType(oType)
 
     def _add_title(self, oCard, sTitle):
         """Add the title to the card."""
-        oCard.addTitle(self._oMaker.make_title(sTitle))
+        oTitle = self._oMaker.make_title(sTitle)
+        if oTitle not in oCard.title:
+            oCard.addTitle(oTitle)
 
     def _add_sect(self, oCard, sSect):
         """Add the sect to the card."""
-        oCard.addSect(self._oMaker.make_sect(sSect))
+        oSect = self._oMaker.make_sect(sSect)
+        if oSect not in oCard.sect:
+            oCard.addSect(oSect)
 
     def _add_physical_cards(self, oCard):
         """Create a physical card for each expansion."""
