@@ -52,12 +52,13 @@ class WriteArdbXML(ArdbInfo):
 
         oCryptElem = SubElement(oRoot, 'crypt', size=str(dCryptStats['size']),
                 min=str(dCryptStats['min']), max=str(dCryptStats['max']),
-                avg=str(dCryptStats['avg']))
+                avg='%.2f' % dCryptStats['avg'])
         self.format_vamps(oCryptElem, dVamps)
 
         oLibElem = SubElement(oRoot, 'library', size=str(iLibSize))
         self.format_library(oLibElem, dLib)
 
+        pretty_xml(oRoot)
         return oRoot
 
     def format_vamps(self, oCryptElem, dVamps):
@@ -79,13 +80,13 @@ class WriteArdbXML(ArdbInfo):
             # these are fine for the xml2html conversion, and look meaningful
             oAdvElem = SubElement(oCardElem, 'adv')
             oNameElem = SubElement(oCardElem, 'name')
+            sName = escape_ardb_name(sName)
             if oCard.level is not None:
                 oAdvElem.text = '(Advanced)'
                 # This is a bit hackish
                 oNameElem.text = sName.replace(' (Advanced)', '')
             else:
                 oNameElem.text = sName
-            sName = escape_ardb_name(sName)
             oSetElem = SubElement(oCardElem, 'set')
             oSetElem.text = sSet
             oDiscElem = SubElement(oCardElem, 'disciplines')
@@ -158,7 +159,6 @@ class WriteArdbXML(ArdbInfo):
            form dCard[(id,name)] = count and writes the file."""
         dCards = self._get_cards(oCardIter)
         oRoot = self.gen_tree(sSetName, sAuthor, sDescription, dCards)
-        pretty_xml(oRoot)
         ElementTree(oRoot).write(fOut)
 
     # pylint: enable-msg=R0913
