@@ -16,6 +16,8 @@ import unittest
 sExpected = """"ELDB - Inventory"
 "Cedric",0,0,"","Crypt"
 "Inez "Nurse216" Villagrande",0,0,"","Crypt"
+"Alan Sovereign",0,0,"","Crypt"
+"Alan Sovereign (ADV)",0,0,"","Crypt"
 "Alexandra",0,0,"","Crypt"
 ".44 Magnum",1,0,"","Library"
 "Ablative Skin",0,0,"","Library"
@@ -25,7 +27,7 @@ sExpected = """"ELDB - Inventory"
 "Anson",0,0,"","Crypt"
 "Kabede Maru",0,0,"","Crypt"
 "Amisa",0,0,"","Crypt"
-"Kemintiri (Advanced)",0,0,"","Crypt"
+"Kemintiri (ADV)",0,0,"","Crypt"
 "Earl "Shaka74" Deams",0,0,"","Crypt"
 "Lazar Dobrescu",0,0,"","Crypt"
 "Abdelsobek",0,0,"","Crypt"
@@ -33,18 +35,19 @@ sExpected = """"ELDB - Inventory"
 "Angelica, The Canonicus",0,0,"","Crypt"
 "Bronwen",0,0,"","Crypt"
 "Alfred Benezri",0,0,"","Crypt"
+"Path of Blood, The",0,0,"","Library"
 "Abjure",0,0,"","Library"
 "Yvette, The Hopeless",0,0,"","Crypt"
 "AK-47",1,0,"","Library"
 "Aire of Elation",0,0,"","Library"
 "Abandoning the Flesh",0,0,"","Library"
-"Aaron's Feeding Razor",0,0,"","Library"
+"Aaron`s Feeding Razor",0,0,"","Library"
 "Aabbt Kindred",0,0,"","Crypt"
 "Abebe",1,0,"","Crypt"
 "Ambrogino Giovanni",0,0,"","Crypt"
-"Aaron Duggan, Cameron's Toady",0,0,"","Crypt"
+"Aaron Duggan, Cameron`s Toady",0,0,"","Crypt"
 "Anna "Dictatrix11" Suljic",0,0,"","Crypt"
-"Predator's Communion",0,0,"","Library"
+"Predator`s Communion",0,0,"","Library"
 "Akram",0,0,"","Crypt"
 "Anastasz di Zagreb",0,0,"","Crypt"
 "Abd al-Rashid",0,0,"","Crypt"
@@ -84,7 +87,8 @@ class ELDBInventoryWriterTests(SutekhTest):
         sData = fIn.read()
         fIn.close()
 
-        self.assertEqual(sorted(sData), sorted(sExpected))
+        self.assertEqual(sorted(sData), sorted(sExpected), "Output differs : "
+                "%s vs %s" % (sData, sExpected))
 
 if __name__ == "__main__":
     unittest.main()
